#[repr(i8)]pub enum BodyCompressionMethod {
Buffer = 0,
}Expand description
Provided for forward compatibility in case we need to support different strategies for compressing the IPC message body (like whole-body compression rather than buffer-level) in the future
Generated from these locations:
- Enum
BodyCompressionMethodin the fileMessage.fbs:58
Variants
Buffer = 0
Each constituent buffer is first compressed with the indicated compressor, and then written with the uncompressed length in the first 8 bytes as a 64-bit little-endian signed integer followed by the compressed buffer bytes (and then padding as required by the protocol). The uncompressed length may be set to -1 to indicate that the data that follows is not compressed, which can be useful for cases where compression does not yield appreciable savings.
Implementations
Sourceimpl BodyCompressionMethod
impl BodyCompressionMethod
Sourcepub const ENUM_VALUES: [Self; 1]
pub const ENUM_VALUES: [Self; 1]
Array containing all valid variants of BodyCompressionMethod