#[repr(i16)]pub enum DictionaryKind {
DenseArray = 0,
}Expand description
Dictionary encoding metadata Maintained for forwards compatibility, in the future Dictionaries might be explicit maps between integers and values allowing for non-contiguous index values
Generated from these locations:
- Enum
DictionaryKindin the fileSchema.fbs:485
Variants
DenseArray = 0
The variant DenseArray in the enum DictionaryKind
Implementations
Sourceimpl DictionaryKind
impl DictionaryKind
Sourcepub const ENUM_VALUES: [Self; 1]
pub const ENUM_VALUES: [Self; 1]
Array containing all valid variants of DictionaryKind