#[repr(i64)]pub enum Feature {
Unused = 0,
DictionaryReplacement = 1,
CompressedBody = 2,
}Expand description
Represents Arrow Features that might not have full support within implementations. This is intended to be used in two scenarios:
- A mechanism for readers of Arrow Streams and files to understand that the stream or file makes use of a feature that isn’t supported or unknown to the implementation (and therefore can meet the Arrow forward compatibility guarantees).
- A means of negotiating between a client and server what features a stream is allowed to use. The enums values here are intended to represent higher level features, additional details may be negotiated with key-value pairs specific to the protocol.
Enums added to this list should be assigned power-of-two values to facilitate exchanging and comparing bitmaps for supported features.
Generated from these locations:
- Enum
Featurein the fileSchema.fbs:71
Variants
Unused = 0
Needed to make flatbuffers happy.
DictionaryReplacement = 1
The stream makes use of multiple full dictionaries with the same ID and assumes clients implement dictionary replacement correctly.
CompressedBody = 2
The stream makes use of compressed bodies as described in Message.fbs.
Implementations