pub struct BinaryView {}Expand description
Logically the same as Binary, but the internal representation uses a view struct that contains the string length and either the string’s entire data inline (for small strings) or an inlined prefix, an index of another buffer, and an offset pointing to a slice in that buffer (for non-small strings).
Since it uses a variable number of data buffers, each Field with this type
must have a corresponding entry in variadicBufferCounts.
Generated from these locations:
- Table
BinaryViewin the fileSchema.fbs:205
Implementations
Sourceimpl BinaryView
impl BinaryView
Sourcepub fn builder() -> BinaryViewBuilder<()>
pub fn builder() -> BinaryViewBuilder<()>
Creates a BinaryViewBuilder for serializing an instance of this table.
pub fn create(builder: &mut Builder) -> Offset<Self>