pub struct BodyCompression {
pub codec: CompressionType,
pub method: BodyCompressionMethod,
}Expand description
Optional compression for the memory buffers constituting IPC message bodies. Intended for use with RecordBatch but could be used for other message types
Generated from these locations:
- Table
BodyCompressionin the fileMessage.fbs:72
Fields
codec: CompressionTypeCompressor library. For LZ4_FRAME, each compressed buffer must consist of a single frame.
method: BodyCompressionMethodIndicates the way the record batch body was compressed
Implementations
Sourceimpl BodyCompression
impl BodyCompression
Sourcepub fn builder() -> BodyCompressionBuilder<()>
pub fn builder() -> BodyCompressionBuilder<()>
Creates a BodyCompressionBuilder for serializing an instance of this table.
pub fn create( builder: &mut Builder, field_codec: impl WriteAsDefault<CompressionType, CompressionType>, field_method: impl WriteAsDefault<BodyCompressionMethod, BodyCompressionMethod>, ) -> Offset<Self>