pub struct Buffer {
pub offset: i64,
pub length: i64,
}Expand description
A Buffer represents a single contiguous memory segment
Generated from these locations:
- Struct
Bufferin the fileSchema.fbs:540
Fields
offset: i64The relative offset into the shared memory page where the bytes for this buffer starts
length: i64The absolute length (in bytes) of the memory buffer. The memory is found from offset (inclusive) to offset + length (non-inclusive). When building messages using the encapsulated IPC message, padding bytes may be written after a buffer, but such padding bytes do not need to be accounted for in the size here.