pub struct Decimal {
pub precision: i32,
pub scale: i32,
pub bit_width: i32,
}Expand description
Exact decimal value represented as an integer value in two’s complement. Currently 32-bit (4-byte), 64-bit (8-byte), 128-bit (16-byte) and 256-bit (32-byte) integers are used. The representation uses the endianness indicated in the Schema.
Generated from these locations:
- Table
Decimalin the fileSchema.fbs:229
Fields
precision: i32Total number of decimal digits
scale: i32Number of digits after the decimal point “.”
bit_width: i32Number of bits per value. The accepted widths are 32, 64, 128 and 256. We use bitWidth for consistency with Int::bitWidth.
Implementations
Sourceimpl Decimal
impl Decimal
Sourcepub fn builder() -> DecimalBuilder<()>
pub fn builder() -> DecimalBuilder<()>
Creates a DecimalBuilder for serializing an instance of this table.
pub fn create( builder: &mut Builder, field_precision: impl WriteAsDefault<i32, i32>, field_scale: impl WriteAsDefault<i32, i32>, field_bit_width: impl WriteAsDefault<i32, i32>, ) -> Offset<Self>