pub struct DictionaryEncoding {
pub id: i64,
pub index_type: Option<Box<Int>>,
pub is_ordered: bool,
pub dictionary_kind: DictionaryKind,
}Expand description
The table DictionaryEncoding in the namespace org.apache.arrow.flatbuf
Generated from these locations:
- Table
DictionaryEncodingin the fileSchema.fbs:486
Fields
id: i64The known dictionary id in the application where this data is used. In the file or streaming formats, the dictionary ids are found in the DictionaryBatch messages
index_type: Option<Box<Int>>The dictionary indices are constrained to be non-negative integers. If this field is null, the indices must be signed int32. To maximize cross-language compatibility and performance, implementations are recommended to prefer signed integer types over unsigned integer types and to avoid uint64 indices unless they are required by an application.
is_ordered: boolBy default, dictionaries are not ordered, or the order does not have semantic meaning. In some statistical, applications, dictionary-encoding is used to represent ordered categorical data, and we provide a way to preserve that metadata here
dictionary_kind: DictionaryKindThe field dictionaryKind in the table DictionaryEncoding
Implementations
Sourceimpl DictionaryEncoding
impl DictionaryEncoding
Sourcepub fn builder() -> DictionaryEncodingBuilder<()>
pub fn builder() -> DictionaryEncodingBuilder<()>
Creates a DictionaryEncodingBuilder for serializing an instance of this table.
pub fn create( builder: &mut Builder, field_id: impl WriteAsDefault<i64, i64>, field_index_type: impl WriteAsOptional<Offset<Int>>, field_is_ordered: impl WriteAsDefault<bool, bool>, field_dictionary_kind: impl WriteAsDefault<DictionaryKind, DictionaryKind>, ) -> Offset<Self>