Struct Field

pub struct Field {
    pub name: Option<String>,
    pub nullable: bool,
    pub type_: Option<Type>,
    pub dictionary: Option<Box<DictionaryEncoding>>,
    pub children: Option<Vec<Field>>,
    pub custom_metadata: Option<Vec<KeyValue>>,
}
A field represents a named column in a record / row batch or child of a nested type.

Generated from these locations:

  • Table Field in the file Schema.fbs:512

Fields

name: Option<String>

Name is not required (e.g., in a List)

nullable: bool

Whether or not this field can contain nulls. Should be true in general.

type_: Option<Type>

This is the type of the decoded value if the field is dictionary encoded.

dictionary: Option<Box<DictionaryEncoding>>

Present only if the field is dictionary encoded.

children: Option<Vec<Field>>

children apply only to nested data types like Struct, List and Union. For primitive types children will have length 0.

custom_metadata: Option<Vec<KeyValue>>

User-defined metadata

Implementations

Source

impl Field

pub fn builder() -> FieldBuilder<()>

Creates a FieldBuilder for serializing an instance of this table.

pub fn create( builder: &mut Builder, field_name: impl WriteAsOptional<Offset<str>>, field_nullable: impl WriteAsDefault<bool, bool>, field_type_: impl WriteAsOptionalUnion<Type>, field_dictionary: impl WriteAsOptional<Offset<DictionaryEncoding>>, field_children: impl WriteAsOptional<Offset<[Offset<Field>]>>, field_custom_metadata: impl WriteAsOptional<Offset<[Offset<KeyValue>]>>, ) -> Offset<Self>