Struct FieldBuilder

pub struct FieldBuilder<State>(/* private fields */);
Builder for serializing an instance of the Field type.

Can be created using the Field::builder method.

Implementations

Source

impl FieldBuilder<()>

pub fn name<T0>(self, value: T0) -> FieldBuilder<(T0,)>

Setter for the name field.

pub fn name_as_null(self) -> FieldBuilder<((),)>

Sets the name field to null.

Source

impl<T0> FieldBuilder<(T0,)>

pub fn nullable<T1>(self, value: T1) -> FieldBuilder<(T0, T1)>
where T1: WriteAsDefault<bool, bool>,

Setter for the nullable field.

pub fn nullable_as_default(self) -> FieldBuilder<(T0, DefaultValue)>

Sets the nullable field to the default value.

Source

impl<T0, T1> FieldBuilder<(T0, T1)>

pub fn type_<T2>(self, value: T2) -> FieldBuilder<(T0, T1, T2)>

Setter for the type field.

pub fn type_as_null(self) -> FieldBuilder<(T0, T1, ())>

Sets the type field to null.

Source

impl<T0, T1, T2> FieldBuilder<(T0, T1, T2)>

pub fn dictionary<T3>(self, value: T3) -> FieldBuilder<(T0, T1, T2, T3)>

Setter for the dictionary field.

pub fn dictionary_as_null(self) -> FieldBuilder<(T0, T1, T2, ())>

Sets the dictionary field to null.

Source

impl<T0, T1, T2, T3> FieldBuilder<(T0, T1, T2, T3)>

pub fn children<T4>(self, value: T4) -> FieldBuilder<(T0, T1, T2, T3, T4)>

Setter for the children field.

pub fn children_as_null(self) -> FieldBuilder<(T0, T1, T2, T3, ())>

Sets the children field to null.

Source

impl<T0, T1, T2, T3, T4> FieldBuilder<(T0, T1, T2, T3, T4)>

pub fn custom_metadata<T5>( self, value: T5, ) -> FieldBuilder<(T0, T1, T2, T3, T4, T5)>

Setter for the custom_metadata field.

pub fn custom_metadata_as_null(self) -> FieldBuilder<(T0, T1, T2, T3, T4, ())>

Sets the custom_metadata field to null.

Source

impl<T0, T1, T2, T3, T4, T5> FieldBuilder<(T0, T1, T2, T3, T4, T5)>

pub fn finish(self, builder: &mut Builder) -> Offset<Field>
where Self: WriteAsOffset<Field>,

Finish writing the builder to get an Offset to a serialized Field.