Struct FooterBuilder

pub struct FooterBuilder<State>(/* private fields */);
Builder for serializing an instance of the Footer type.

Can be created using the Footer::builder method.

Implementations

Source

impl FooterBuilder<()>

pub fn version<T0>(self, value: T0) -> FooterBuilder<(T0,)>

Setter for the version field.

pub fn version_as_default(self) -> FooterBuilder<(DefaultValue,)>

Sets the version field to the default value.

Source

impl<T0> FooterBuilder<(T0,)>

pub fn schema<T1>(self, value: T1) -> FooterBuilder<(T0, T1)>

Setter for the schema field.

pub fn schema_as_null(self) -> FooterBuilder<(T0, ())>

Sets the schema field to null.

Source

impl<T0, T1> FooterBuilder<(T0, T1)>

pub fn dictionaries<T2>(self, value: T2) -> FooterBuilder<(T0, T1, T2)>

Setter for the dictionaries field.

pub fn dictionaries_as_null(self) -> FooterBuilder<(T0, T1, ())>

Sets the dictionaries field to null.

Source

impl<T0, T1, T2> FooterBuilder<(T0, T1, T2)>

pub fn record_batches<T3>(self, value: T3) -> FooterBuilder<(T0, T1, T2, T3)>

Setter for the recordBatches field.

pub fn record_batches_as_null(self) -> FooterBuilder<(T0, T1, T2, ())>

Sets the recordBatches field to null.

Source

impl<T0, T1, T2, T3> FooterBuilder<(T0, T1, T2, T3)>

pub fn custom_metadata<T4>( self, value: T4, ) -> FooterBuilder<(T0, T1, T2, T3, T4)>

Setter for the custom_metadata field.

pub fn custom_metadata_as_null(self) -> FooterBuilder<(T0, T1, T2, T3, ())>

Sets the custom_metadata field to null.

Source

impl<T0, T1, T2, T3, T4> FooterBuilder<(T0, T1, T2, T3, T4)>

pub fn finish(self, builder: &mut Builder) -> Offset<Footer>
where Self: WriteAsOffset<Footer>,

Finish writing the builder to get an Offset to a serialized Footer.