pub struct KeyValue {
pub key: Option<String>,
pub value: Option<String>,
}Expand description
user defined key value pairs to add custom metadata to arrow key namespacing is the responsibility of the user
Generated from these locations:
- Table
KeyValuein the fileSchema.fbs:475
Fields
key: Option<String>The field key in the table KeyValue
value: Option<String>The field value in the table KeyValue
Implementations
Sourceimpl KeyValue
impl KeyValue
Sourcepub fn builder() -> KeyValueBuilder<()>
pub fn builder() -> KeyValueBuilder<()>
Creates a KeyValueBuilder for serializing an instance of this table.
pub fn create( builder: &mut Builder, field_key: impl WriteAsOptional<Offset<str>>, field_value: impl WriteAsOptional<Offset<str>>, ) -> Offset<Self>