pub struct ListView {}Expand description
Represents the same logical types that List can, but contains offsets and sizes allowing for writes in any order and sharing of child values among list values.
Generated from these locations:
- Table
ListViewin the fileSchema.fbs:105
Implementations