pub struct Map {
pub keys_sorted: bool,
}Expand description
A Map is a logical nested type that is represented as
List<entries: Struct<key: K, value: V>>
In this layout, the keys and values are each respectively contiguous. We do not constrain the key and value types, so the application is responsible for ensuring that the keys are hashable and unique. Whether the keys are sorted may be set in the metadata for this field.
In a field with Map type, the field has a child Struct field, which then has two children: key type and the second the value type. The names of the child fields may be respectively “entries”, “key”, and “value”, but this is not enforced.
Map
- child[0] entries: Struct
- child[0] key: K
- child[1] value: VNeither the “entries” field nor the “key” field may be nullable.
The metadata is structured so that Arrow systems without special handling for Map can make Map an alias for List. The “layout” attribute for the Map field must have the same contents as a List.
Generated from these locations:
- Table
Mapin the fileSchema.fbs:143
Fields
keys_sorted: boolSet to true if the keys within each value are sorted
Implementations
Sourceimpl Map
impl Map
Sourcepub fn builder() -> MapBuilder<()>
pub fn builder() -> MapBuilder<()>
Creates a MapBuilder for serializing an instance of this table.
pub fn create( builder: &mut Builder, field_keys_sorted: impl WriteAsDefault<bool, bool>, ) -> Offset<Self>