pub struct RunEndEncoded {}Expand description
Contains two child arrays, run_ends and values. The run_ends child array must be a 16/32/64-bit integer array which encodes the indices at which the run with the value in each corresponding index in the values child array ends. Like list/struct types, the value array can be of any type.
Generated from these locations:
- Table
RunEndEncodedin the fileSchema.fbs:222
Implementations
Sourceimpl RunEndEncoded
impl RunEndEncoded
Sourcepub fn builder() -> RunEndEncodedBuilder<()>
pub fn builder() -> RunEndEncodedBuilder<()>
Creates a RunEndEncodedBuilder for serializing an instance of this table.
pub fn create(builder: &mut Builder) -> Offset<Self>