pub struct Schema {
pub endianness: Endianness,
pub fields: Option<Vec<Field>>,
pub custom_metadata: Option<Vec<KeyValue>>,
pub features: Option<Vec<Feature>>,
}Expand description
A Schema describes the columns in a row batch
Generated from these locations:
- Table
Schemain the fileSchema.fbs:556
Fields
endianness: Endiannessendianness of the buffer it is Little Endian by default if endianness doesn’t match the underlying system then the vectors need to be converted
fields: Option<Vec<Field>>The field fields in the table Schema
custom_metadata: Option<Vec<KeyValue>>The field custom_metadata in the table Schema
features: Option<Vec<Feature>>Features used in the stream/file.
Implementations
Sourceimpl Schema
impl Schema
Sourcepub fn builder() -> SchemaBuilder<()>
pub fn builder() -> SchemaBuilder<()>
Creates a SchemaBuilder for serializing an instance of this table.
pub fn create( builder: &mut Builder, field_endianness: impl WriteAsDefault<Endianness, Endianness>, field_fields: impl WriteAsOptional<Offset<[Offset<Field>]>>, field_custom_metadata: impl WriteAsOptional<Offset<[Offset<KeyValue>]>>, field_features: impl WriteAsOptional<Offset<[Feature]>>, ) -> Offset<Self>