Struct SparseMatrixIndexCsx

pub struct SparseMatrixIndexCsx {
    pub compressed_axis: SparseMatrixCompressedAxis,
    pub indptr_type: Box<Int>,
    pub indptr_buffer: Buffer,
    pub indices_type: Box<Int>,
    pub indices_buffer: Buffer,
}
Compressed Sparse format, that is matrix-specific.

Generated from these locations:

  • Table SparseMatrixIndexCSX in the file SparseTensor.fbs:80

Fields

compressed_axis: SparseMatrixCompressedAxis

Which axis, row or column, is compressed

indptr_type: Box<Int>

The type of values in indptrBuffer

indptr_buffer: Buffer

indptrBuffer stores the location and size of indptr array that represents the range of the rows. The i-th row spans from indptr[i] to indptr[i+1] in the data. The length of this array is 1 + (the number of rows), and the type of index value is long.

For example, let X be the following 6x4 matrix:

  X := [[0, 1, 2, 0],
        [0, 0, 3, 0],
        [0, 4, 0, 5],
        [0, 0, 0, 0],
        [6, 0, 7, 8],
        [0, 9, 0, 0]].

The array of non-zero values in X is:

  values(X) = [1, 2, 3, 4, 5, 6, 7, 8, 9].

And the indptr of X is:

  indptr(X) = [0, 2, 3, 5, 5, 8, 10].
indices_type: Box<Int>

The type of values in indicesBuffer

indices_buffer: Buffer

indicesBuffer stores the location and size of the array that contains the column indices of the corresponding non-zero values. The type of index value is long.

For example, the indices of the above X is:

  indices(X) = [1, 2, 2, 1, 3, 0, 2, 3, 1].

Note that the indices are sorted in lexicographical order for each row.

Implementations

Source

impl SparseMatrixIndexCsx

pub fn builder() -> SparseMatrixIndexCsxBuilder<()>

Creates a SparseMatrixIndexCsxBuilder for serializing an instance of this table.

pub fn create( builder: &mut Builder, field_compressed_axis: impl WriteAsDefault<SparseMatrixCompressedAxis, SparseMatrixCompressedAxis>, field_indptr_type: impl WriteAs<Offset<Int>>, field_indptr_buffer: impl WriteAs<Buffer>, field_indices_type: impl WriteAs<Offset<Int>>, field_indices_buffer: impl WriteAs<Buffer>, ) -> Offset<Self>