pub struct SparseTensor {
pub type_: Type,
pub shape: Vec<TensorDim>,
pub non_zero_length: i64,
pub sparse_index: SparseTensorIndex,
pub data: Buffer,
}Expand description
The table SparseTensor in the namespace org.apache.arrow.flatbuf
Generated from these locations:
- Table
SparseTensorin the fileSparseTensor.fbs:209
Fields
type_: TypeThe type of data contained in a value cell. Currently only fixed-width value types are supported, no strings or nested types.
shape: Vec<TensorDim>The dimensions of the tensor, optionally named.
non_zero_length: i64The number of non-zero values in a sparse tensor.
sparse_index: SparseTensorIndexSparse tensor index
data: BufferThe location and size of the tensor’s data
Implementations
Sourceimpl SparseTensor
impl SparseTensor
Sourcepub fn builder() -> SparseTensorBuilder<()>
pub fn builder() -> SparseTensorBuilder<()>
Creates a SparseTensorBuilder for serializing an instance of this table.
pub fn create( builder: &mut Builder, field_type_: impl WriteAsUnion<Type>, field_shape: impl WriteAs<Offset<[Offset<TensorDim>]>>, field_non_zero_length: impl WriteAsDefault<i64, i64>, field_sparse_index: impl WriteAsUnion<SparseTensorIndex>, field_data: impl WriteAs<Buffer>, ) -> Offset<Self>