Struct SparseTensorIndexCoo

pub struct SparseTensorIndexCoo {
    pub indices_type: Box<Int>,
    pub indices_strides: Option<Vec<i64>>,
    pub indices_buffer: Buffer,
    pub is_canonical: bool,
}
EXPERIMENTAL: Data structures for sparse tensors Coordinate (COO) format of sparse tensor index.

COO’s index list are represented as a NxM matrix, where N is the number of non-zero values, and M is the number of dimensions of a sparse tensor.

indicesBuffer stores the location and size of the data of this indices matrix. The value type and the stride of the indices matrix is specified in indicesType and indicesStrides fields.

For example, let X be a 2x3x4x5 tensor, and it has the following 6 non-zero values:

  X[0, 1, 2, 0] := 1
  X[1, 1, 2, 3] := 2
  X[0, 2, 1, 0] := 3
  X[0, 1, 3, 0] := 4
  X[0, 1, 2, 1] := 5
  X[1, 2, 0, 4] := 6

In COO format, the index matrix of X is the following 4x6 matrix:

  [[0, 0, 0, 0, 1, 1],
   [1, 1, 1, 2, 1, 2],
   [2, 2, 3, 1, 2, 0],
   [0, 1, 0, 0, 3, 4]]

When isCanonical is true, the indices is sorted in lexicographical order (row-major order), and it does not have duplicated entries. Otherwise, the indices may not be sorted, or may have duplicated entries.

Generated from these locations:

  • Table SparseTensorIndexCOO in the file SparseTensor.fbs:58

Fields

indices_type: Box<Int>

The type of values in indicesBuffer

indices_strides: Option<Vec<i64>>

Non-negative byte offsets to advance one value cell along each dimension If omitted, default to row-major order (C-like).

indices_buffer: Buffer

The location and size of the indices matrix’s data

is_canonical: bool

This flag is true if and only if the indices matrix is sorted in row-major order, and does not have duplicated entries. This sort order is the same as of Tensorflow’s SparseTensor, but it is inverse order of SciPy’s canonical coo_matrix (SciPy employs column-major order for its coo_matrix).

Implementations

Source

impl SparseTensorIndexCoo

pub fn builder() -> SparseTensorIndexCooBuilder<()>

Creates a SparseTensorIndexCooBuilder for serializing an instance of this table.

pub fn create( builder: &mut Builder, field_indices_type: impl WriteAs<Offset<Int>>, field_indices_strides: impl WriteAsOptional<Offset<[i64]>>, field_indices_buffer: impl WriteAs<Buffer>, field_is_canonical: impl WriteAsDefault<bool, bool>, ) -> Offset<Self>