pub struct Struct {}Expand description
A Struct_ in the flatbuffer metadata is the same as an Arrow Struct (according to the physical memory layout). We used Struct_ here as Struct is a reserved word in Flatbuffers
Generated from these locations:
- Table
Struct_in the fileSchema.fbs:91
Implementations