pub struct Tensor {
pub type_: Type,
pub shape: Vec<TensorDim>,
pub strides: Option<Vec<i64>>,
pub data: Buffer,
}Expand description
The table Tensor in the namespace org.apache.arrow.flatbuf
Generated from these locations:
- Table
Tensorin the fileTensor.fbs:38
Fields
type_: TypeThe type of data contained in a value cell. Currently only fixed-width value types are supported, no strings or nested types
shape: Vec<TensorDim>The dimensions of the tensor, optionally named
strides: Option<Vec<i64>>Non-negative byte offsets to advance one value cell along each dimension If omitted, default to row-major order (C-like).
data: BufferThe location and size of the tensor’s data
Implementations
Sourceimpl Tensor
impl Tensor
Sourcepub fn builder() -> TensorBuilder<()>
pub fn builder() -> TensorBuilder<()>
Creates a TensorBuilder for serializing an instance of this table.
pub fn create( builder: &mut Builder, field_type_: impl WriteAsUnion<Type>, field_shape: impl WriteAs<Offset<[Offset<TensorDim>]>>, field_strides: impl WriteAsOptional<Offset<[i64]>>, field_data: impl WriteAs<Buffer>, ) -> Offset<Self>