Struct Time

pub struct Time {
    pub unit: TimeUnit,
    pub bit_width: i32,
}
Time is either a 32-bit or 64-bit signed integer type representing an elapsed time since midnight, stored in either of four units: seconds, milliseconds, microseconds or nanoseconds.

The integer bitWidth depends on the unit and must be one of the following:

  • SECOND and MILLISECOND: 32 bits
  • MICROSECOND and NANOSECOND: 64 bits

The allowed values are between 0 (inclusive) and 86400 (=246060) seconds (exclusive), adjusted for the time unit (for example, up to 86400000 exclusive for the MILLISECOND unit). This definition doesn’t allow for leap seconds. Time values from measurements with leap seconds will need to be corrected when ingesting into Arrow (for example by replacing the value 86400 with 86399).

Generated from these locations:

  • Table Time in the file Schema.fbs:272

Fields

unit: TimeUnit

The field unit in the table Time

bit_width: i32

The field bitWidth in the table Time

Implementations

Source

impl Time

pub fn builder() -> TimeBuilder<()>

Creates a TimeBuilder for serializing an instance of this table.

pub fn create( builder: &mut Builder, field_unit: impl WriteAsDefault<TimeUnit, TimeUnit>, field_bit_width: impl WriteAsDefault<i32, i32>, ) -> Offset<Self>