Struct Union

pub struct Union {
    pub mode: UnionMode,
    pub type_ids: Option<Vec<i32>>,
}
A union is a complex type with children in Field By default ids in the type vector refer to the offsets in the children optionally typeIds provides an indirection between the child offset and the type id for each child typeIds[offset] is the id used in the type vector

Generated from these locations:

  • Table Union in the file Schema.fbs:154

Fields

mode: UnionMode

The field mode in the table Union

type_ids: Option<Vec<i32>>

The field typeIds in the table Union

Implementations

Source

impl Union

pub fn builder() -> UnionBuilder<()>

Creates a UnionBuilder for serializing an instance of this table.

pub fn create( builder: &mut Builder, field_mode: impl WriteAsDefault<UnionMode, UnionMode>, field_type_ids: impl WriteAsOptional<Offset<[i32]>>, ) -> Offset<Self>