pub struct Utf8View {}Expand description
Logically the same as Utf8, but the internal representation uses a view struct that contains the string length and either the string’s entire data inline (for small strings) or an inlined prefix, an index of another buffer, and an offset pointing to a slice in that buffer (for non-small strings).
Since it uses a variable number of data buffers, each Field with this type
must have a corresponding entry in variadicBufferCounts.
Generated from these locations:
- Table
Utf8Viewin the fileSchema.fbs:195
Implementations