pub enum MessageHeader {
Schema(Box<Schema>),
DictionaryBatch(Box<DictionaryBatch>),
RecordBatch(Box<RecordBatch>),
Tensor(Box<Tensor>),
SparseTensor(Box<SparseTensor>),
}Expand description
The root Message type This union enables us to easily send different message types without redundant storage, and in the future we can easily add new message types.
Arrow implementations do not need to implement all of the message types, which may include experimental metadata types. For maximum compatibility, it is best to send data using RecordBatch
Generated from these locations:
- Union
MessageHeaderin the fileMessage.fbs:146
Variants
Schema(Box<Schema>)
The variant of type Schema in the union MessageHeader
DictionaryBatch(Box<DictionaryBatch>)
The variant of type DictionaryBatch in the union MessageHeader
RecordBatch(Box<RecordBatch>)
The variant of type RecordBatch in the union MessageHeader
Tensor(Box<Tensor>)
The variant of type Tensor in the union MessageHeader
SparseTensor(Box<SparseTensor>)
The variant of type SparseTensor in the union MessageHeader
Implementations
Sourceimpl MessageHeader
impl MessageHeader
Sourcepub fn builder() -> MessageHeaderBuilder<Uninitialized>
pub fn builder() -> MessageHeaderBuilder<Uninitialized>
Creates a MessageHeaderBuilder for serializing an instance of this table.
pub fn create_schema( builder: &mut Builder, value: impl WriteAsOffset<Schema>, ) -> UnionOffset<Self>
pub fn create_dictionary_batch( builder: &mut Builder, value: impl WriteAsOffset<DictionaryBatch>, ) -> UnionOffset<Self>
pub fn create_record_batch( builder: &mut Builder, value: impl WriteAsOffset<RecordBatch>, ) -> UnionOffset<Self>
pub fn create_tensor( builder: &mut Builder, value: impl WriteAsOffset<Tensor>, ) -> UnionOffset<Self>
pub fn create_sparse_tensor( builder: &mut Builder, value: impl WriteAsOffset<SparseTensor>, ) -> UnionOffset<Self>