pub struct RecordBatch {
pub length: i64,
pub nodes: Option<Vec<FieldNode>>,
pub buffers: Option<Vec<Buffer>>,
pub compression: Option<Box<BodyCompression>>,
pub variadic_buffer_counts: Option<Vec<i64>>,
}Expand description
A data header describing the shared memory layout of a “record” or “row” batch. Some systems call this a “row batch” internally and others a “record batch”.
Generated from these locations:
- Table
RecordBatchin the fileMessage.fbs:84
Fields
length: i64number of records / rows. The arrays in the batch should all have this length
nodes: Option<Vec<FieldNode>>Nodes correspond to the pre-ordered flattened logical schema
buffers: Option<Vec<Buffer>>Buffers correspond to the pre-ordered flattened buffer tree
The number of buffers appended to this list depends on the schema. For example, most primitive arrays will have 2 buffers, 1 for the validity bitmap and 1 for the values. For struct arrays, there will only be a single buffer for the validity (nulls) bitmap
compression: Option<Box<BodyCompression>>Optional compression of the message body
variadic_buffer_counts: Option<Vec<i64>>Some types such as Utf8View are represented using a variable number of buffers. For each such Field in the pre-ordered flattened logical schema, there will be an entry in variadicBufferCounts to indicate the number of number of variadic buffers which belong to that Field in the current RecordBatch.
For example, the schema
col1: Struct<alpha: Int32, beta: BinaryView, gamma: Float64>
col2: Utf8View
contains two Fields with variadic buffers so variadicBufferCounts will have
two entries, the first counting the variadic buffers of col1.beta and the
second counting col2’s.
This field may be omitted if and only if the schema contains no Fields with a variable number of buffers, such as BinaryView and Utf8View.
Implementations
Sourceimpl RecordBatch
impl RecordBatch
Sourcepub fn builder() -> RecordBatchBuilder<()>
pub fn builder() -> RecordBatchBuilder<()>
Creates a RecordBatchBuilder for serializing an instance of this table.
pub fn create( builder: &mut Builder, field_length: impl WriteAsDefault<i64, i64>, field_nodes: impl WriteAsOptional<Offset<[FieldNode]>>, field_buffers: impl WriteAsOptional<Offset<[Buffer]>>, field_compression: impl WriteAsOptional<Offset<BodyCompression>>, field_variadic_buffer_counts: impl WriteAsOptional<Offset<[i64]>>, ) -> Offset<Self>