pub struct SparseTensorIndexCsf {
pub indptr_type: Box<Int>,
pub indptr_buffers: Vec<Buffer>,
pub indices_type: Box<Int>,
pub indices_buffers: Vec<Buffer>,
pub axis_order: Vec<i32>,
}Expand description
Compressed Sparse Fiber (CSF) sparse tensor index.
Generated from these locations:
- Table
SparseTensorIndexCSFin the fileSparseTensor.fbs:128
Fields
indptr_type: Box<Int>CSF is a generalization of compressed sparse row (CSR) index. See smith2017knl
CSF index recursively compresses each dimension of a tensor into a set of prefix trees. Each path from a root to leaf forms one tensor non-zero index. CSF is implemented with two arrays of buffers and one arrays of integers.
For example, let X be a 2x3x4x5 tensor and let it have the following 8 non-zero values:
X[0, 0, 0, 1] := 1
X[0, 0, 0, 2] := 2
X[0, 1, 0, 0] := 3
X[0, 1, 0, 2] := 4
X[0, 1, 1, 0] := 5
X[1, 1, 1, 0] := 6
X[1, 1, 1, 1] := 7
X[1, 1, 1, 2] := 8As a prefix tree this would be represented as:
0 1
/ \ |
0 1 1
/ / \ |
0 0 1 1
/| /| | /| |
1 2 0 2 0 0 1 2The type of values in indptrBuffers
indptr_buffers: Vec<Buffer>indptrBuffers stores the sparsity structure.
Each two consecutive dimensions in a tensor correspond to a buffer in
indptrBuffers. A pair of consecutive values at indptrBuffers[dim][i]
and indptrBuffers[dim][i + 1] signify a range of nodes in
indicesBuffers[dim + 1] who are children of indicesBuffers[dim][i] node.
For example, the indptrBuffers for the above X is:
indptrBuffer(X) = [
[0, 2, 3],
[0, 1, 3, 4],
[0, 2, 4, 5, 8]
].indices_type: Box<Int>The type of values in indicesBuffers
indices_buffers: Vec<Buffer>indicesBuffers stores values of nodes. Each tensor dimension corresponds to a buffer in indicesBuffers. For example, the indicesBuffers for the above X is:
indicesBuffer(X) = [
[0, 1],
[0, 1, 1],
[0, 0, 1, 1],
[1, 2, 0, 2, 0, 0, 1, 2]
].axis_order: Vec<i32>axisOrder stores the sequence in which dimensions were traversed to produce the prefix tree. For example, the axisOrder for the above X is:
axisOrder(X) = [0, 1, 2, 3].Implementations
Sourceimpl SparseTensorIndexCsf
impl SparseTensorIndexCsf
Sourcepub fn builder() -> SparseTensorIndexCsfBuilder<()>
pub fn builder() -> SparseTensorIndexCsfBuilder<()>
Creates a SparseTensorIndexCsfBuilder for serializing an instance of this table.
pub fn create( builder: &mut Builder, field_indptr_type: impl WriteAs<Offset<Int>>, field_indptr_buffers: impl WriteAs<Offset<[Buffer]>>, field_indices_type: impl WriteAs<Offset<Int>>, field_indices_buffers: impl WriteAs<Offset<[Buffer]>>, field_axis_order: impl WriteAs<Offset<[i32]>>, ) -> Offset<Self>